@@ -661,6 +661,23 @@ slot_list_call(const Container& slot_list, Arg1 arg1) {
   (*first)(arg1);
 }
 
+template <typename Container, typename Arg1, typename Arg2, typename Arg3, typename Arg4>
+inline void
+slot_list_call(const Container& slot_list, Arg1 arg1, Arg2 arg2, Arg3 arg3, Arg4 arg4) {
+  if (slot_list.empty())
+    return;
+
+  typename Container::const_iterator first = slot_list.begin();
+  typename Container::const_iterator next = slot_list.begin();
+
+  while (++next != slot_list.end()) {
+    (*first)(arg1, arg2, arg3, arg4);
+    first = next;
+  }
+
+  (*first)(arg1, arg2, arg3, arg4);
+}
+
 }
 
 #endif
