@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005-2007, Jari Sundell
+// Copyright (C) 2005-2011, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -56,6 +56,10 @@ const int e_handshake_unencrypted_rejected      = 9;
 const int e_handshake_invalid_encryption        = 10;
 const int e_handshake_encryption_sync_failed    = 11;
 const int e_handshake_network_error             = 12;
+const int e_handshake_network_unreachable       = 13;
+const int e_handshake_network_timeout           = 14;
+const int e_handshake_invalid_order             = 15;
+const int e_handshake_toomanyfailed             = 16;
 
 // const int e_handshake_incoming                  = 13;
 // const int e_handshake_outgoing                  = 14;
@@ -65,7 +69,7 @@ const int e_handshake_network_error             = 12;
 // const int e_handshake_retry_plaintext           = 18;
 // const int e_handshake_retry_encrypted           = 19;
 
-const int e_last                                = 12;
+const int e_last                                = 16;
 
 const char* strerror(int err) LIBTORRENT_EXPORT;
 
