@@ -38,8 +38,14 @@
 
 #include <cerrno>
 #include <cstring>
+#include <netdb.h>
+#include <sstream>
 #include <unistd.h>
 
+#ifdef USE_EXECINFO
+#include <execinfo.h>
+#endif
+
 #include "exceptions.h"
 
 namespace torrent {
@@ -48,7 +54,6 @@ namespace torrent {
 // exceptions. This allows us to create breakpoints at throws. This is
 // limited to rarely thrown exceptions.
 
-void internal_error::initialize(const std::string& msg) { m_msg = msg; } // while (true) sleep(1); }
 void communication_error::initialize(const std::string& msg) { m_msg = msg; }
 void storage_error::initialize(const std::string& msg) { m_msg = msg; }
 void resource_error::initialize(const std::string& msg) { m_msg = msg; }
@@ -59,4 +64,32 @@ connection_error::what() const throw() {
   return std::strerror(m_errno);
 }
 
+const char*
+address_info_error::what() const throw() {
+  return ::gai_strerror(m_errno);
+}
+
+void
+internal_error::initialize(const std::string& msg) {
+  m_msg = msg;
+
+  std::stringstream output;
+
+#ifdef USE_EXECINFO
+  void* stackPtrs[20];
+
+  // Print the stack and exit.
+  int stackSize = ::backtrace(stackPtrs, 20);
+  char** stackStrings = backtrace_symbols(stackPtrs, stackSize);
+
+  for (int i = 0; i < stackSize; ++i)
+    output << stackStrings[i] << std::endl;
+
+#else
+  output << "Stack dump not enabled." << std::endl;
+#endif
+
+  m_backtrace = output.str();
+}
+
 }
