@@ -55,14 +55,17 @@ Http::trigger_done() {
   if (signal_done().empty())
     lt_log_print(LOG_TRACKER_INFO, "Disowned tracker done: url:'%s'.", m_url.c_str());
 
+  bool should_delete_self = (m_flags & flag_delete_self);
+  bool should_delete_stream = (m_flags & flag_delete_stream);
+
   rak::slot_list_call(signal_done());
 
-  if (m_flags & flag_delete_stream) {
+  if (should_delete_stream) {
     delete m_stream;
     m_stream = NULL;
   }
 
-  if (m_flags & flag_delete_self)
+  if (should_delete_self)
     delete this;
 }
 
@@ -71,14 +74,17 @@ Http::trigger_failed(const std::string& message) {
   if (signal_done().empty())
     lt_log_print(LOG_TRACKER_INFO, "Disowned tracker failed: url:'%s'.", m_url.c_str());
 
+  bool should_delete_self = (m_flags & flag_delete_self);
+  bool should_delete_stream = (m_flags & flag_delete_stream);
+
   rak::slot_list_call(signal_failed(), message);
 
-  if (m_flags & flag_delete_stream) {
+  if (should_delete_stream) {
     delete m_stream;
     m_stream = NULL;
   }
 
-  if (m_flags & flag_delete_self)
+  if (should_delete_self)
     delete this;
 }
 
