@@ -40,6 +40,7 @@
 #include <iostream>
 #include <cmath>
 #include <limits>
+#include <stdexcept>
 #include <rak/algorithm.h>
 #include <rak/string_manip.h>
 
@@ -59,7 +60,12 @@ object_read_string(std::istream* input, std::string& str) {
   if (input->fail() || input->get() != ':')
     return false;
   
-  str.resize(size);
+  try {
+  	str.resize(size);
+  }
+  catch (std::length_error& e){ 
+	  return false;
+  }
 
   for (std::string::iterator itr = str.begin(); itr != str.end() && input->good(); ++itr)
     *itr = input->get();
@@ -104,7 +110,8 @@ object_read_bencode_c_string(const char* first, const char* last) {
   while (first != last && *first >= '0' && *first <= '9')
     length = length * 10 + (*first++ - '0');
 
-  if (length + 1 > (unsigned int)std::distance(first, last) || *first++ != ':')
+  if (length + 1 > (unsigned int)std::distance(first, last) || length + 1 == 0
+		  || *first++ != ':')
     throw torrent::bencode_error("Invalid bencode data.");
   
   return raw_string(first, length);
