@@ -40,9 +40,10 @@
 
 #include <sys/types.h>
 
-#include <torrent/connection_manager.h>
 #include <cstdio>
 
+#include "rak/error_number.h"
+
 #include "net/address_list.h"
 #include "torrent/exceptions.h"
 #include "torrent/connection_manager.h"
@@ -51,28 +52,29 @@
 #include "torrent/tracker_list.h"
 #include "torrent/utils/log.h"
 #include "torrent/utils/option_strings.h"
+#include "torrent/utils/uri_parser.h"
 
 #include "tracker_udp.h"
 #include "manager.h"
 
-namespace tr1 { using namespace std::tr1; }
-
 #define LT_LOG_TRACKER(log_level, log_fmt, ...)                         \
-  lt_log_print_info(LOG_TRACKER_##log_level, m_parent->info(), "tracker", "[%u] " log_fmt, group(), __VA_ARGS__);
+  lt_log_print_info(LOG_TRACKER_##log_level, m_parent->info(), "tracker_udp", "[%u] " log_fmt, group(), __VA_ARGS__);
 
 #define LT_LOG_TRACKER_DUMP(log_level, log_dump_data, log_dump_size, log_fmt, ...)                   \
-  lt_log_print_info_dump(LOG_TRACKER_##log_level, log_dump_data, log_dump_size, m_parent->info(), "tracker", "[%u] " log_fmt, group(), __VA_ARGS__);
+  lt_log_print_info_dump(LOG_TRACKER_##log_level, log_dump_data, log_dump_size, m_parent->info(), "tracker_udp", "[%u] " log_fmt, group(), __VA_ARGS__);
 
 namespace torrent {
 
 TrackerUdp::TrackerUdp(TrackerList* parent, const std::string& url, int flags) :
   Tracker(parent, url, flags),
 
+  m_port(0),
+
   m_slot_resolver(NULL),
   m_readBuffer(NULL),
   m_writeBuffer(NULL) {
 
-  m_taskTimeout.slot() = std::tr1::bind(&TrackerUdp::receive_timeout, this);
+  m_taskTimeout.slot() = std::bind(&TrackerUdp::receive_timeout, this);
 }
 
 TrackerUdp::~TrackerUdp() {
@@ -94,12 +96,14 @@ TrackerUdp::send_state(int state) {
   close_directly();
   m_latest_event = state;
 
-  char hostname[1024];
-      
-  if (std::sscanf(m_url.c_str(), "udp://%1023[^:]:%i", hostname, &m_port) != 2 ||
-      hostname[0] == '\0' ||
-      m_port <= 0 || m_port >= (1 << 16))
-    return receive_failed("Could not parse UDP hostname or port.");
+  hostname_type hostname;
+
+  if (!parse_udp_url(m_url, hostname, m_port))
+    return receive_failed("could not parse hostname or port");
+
+  LT_LOG_TRACKER(DEBUG, "hostname lookup (address:%s)", hostname.data());
+
+  m_sendState = state;
 
   // Because we can only remember one slot, set any pending resolves blocked
   // so that if this tracker is deleted, the member function won't be called.
@@ -108,12 +112,29 @@ TrackerUdp::send_state(int state) {
     m_slot_resolver = NULL;
   }
 
-  m_sendState = state;
-  m_slot_resolver = manager->connection_manager()->resolver()(hostname, PF_INET, SOCK_DGRAM,
-                                                              tr1::bind(&TrackerUdp::start_announce,
-                                                                        this,
-                                                                        tr1::placeholders::_1,
-                                                                        tr1::placeholders::_2));
+  m_slot_resolver = make_resolver_slot(hostname);
+}
+
+bool
+TrackerUdp::parse_udp_url(const std::string& url, hostname_type& hostname, int& port) const {
+  if (std::sscanf(m_url.c_str(), "udp://%1023[^:]:%i", hostname.data(), &port) == 2 && hostname[0] != '\0' &&
+      port > 0 && port < (1 << 16))
+    return true;
+
+  if (std::sscanf(m_url.c_str(), "udp://[%1023[^]]]:%i", hostname.data(), &port) == 2 && hostname[0] != '\0' &&
+      port > 0 && port < (1 << 16))
+    return true;
+
+  return false;
+}
+
+TrackerUdp::resolver_type*
+TrackerUdp::make_resolver_slot(const hostname_type& hostname) {
+  return manager->connection_manager()->resolver()(hostname.data(), PF_UNSPEC, SOCK_DGRAM,
+                                                   std::bind(&TrackerUdp::start_announce,
+                                                             this,
+                                                             std::placeholders::_1,
+                                                             std::placeholders::_2));
 }
 
 void
@@ -124,18 +145,24 @@ TrackerUdp::start_announce(const sockaddr* sa, int err) {
   }
 
   if (sa == NULL)
-    return receive_failed("Could not resolve hostname.");
+    return receive_failed("could not resolve hostname");
 
   m_connectAddress = *rak::socket_address::cast_from(sa);
   m_connectAddress.set_port(m_port);
 
-  if (!m_connectAddress.is_valid())
-    return receive_failed("Invalid tracker address.");
+  LT_LOG_TRACKER(DEBUG, "address found (address:%s)", m_connectAddress.address_str().c_str());
 
-  if (!get_fd().open_datagram() ||
-      !get_fd().set_nonblock() ||
-      !get_fd().bind(*rak::socket_address::cast_from(manager->connection_manager()->bind_address())))
-    return receive_failed("Could not open UDP socket.");
+  if (!m_connectAddress.is_valid())
+    return receive_failed("invalid tracker address");
+
+  // TODO: Make each of these a separate error... at the very least separate open and bind.
+  if (!get_fd().open_datagram() || !get_fd().set_nonblock())
+    return receive_failed("could not open UDP socket");
+
+  auto bind_address = rak::socket_address::cast_from(manager->connection_manager()->bind_address());
+
+  if (bind_address->is_bindable() && !get_fd().bind(*bind_address))
+    return receive_failed("failed to bind socket to udp address '" + bind_address->pretty_address_str() + "' with error '" + rak::error_number::current().c_str() + "'");
 
   m_readBuffer = new ReadBuffer;
   m_writeBuffer = new WriteBuffer;
@@ -156,7 +183,7 @@ TrackerUdp::close() {
   if (!get_fd().is_valid())
     return;
 
-  LT_LOG_TRACKER(DEBUG, "Tracker UDP request cancelled: state:%s url:%s.",
+  LT_LOG_TRACKER(DEBUG, "request cancelled (state:%s url:%s)",
                  option_as_string(OPTION_TRACKER_EVENT, m_latest_event), m_url.c_str());
 
   close_directly();
@@ -167,7 +194,7 @@ TrackerUdp::disown() {
   if (!get_fd().is_valid())
     return;
 
-  LT_LOG_TRACKER(DEBUG, "Tracker UDP request disowned: state:%s url:%s.",
+  LT_LOG_TRACKER(DEBUG, "request disowned (state:%s url:%s)",
                  option_as_string(OPTION_TRACKER_EVENT, m_latest_event), m_url.c_str());
 
   close_directly();
@@ -212,7 +239,7 @@ TrackerUdp::receive_timeout() {
     throw internal_error("TrackerUdp::receive_timeout() called but m_taskTimeout is still scheduled.");
 
   if (--m_tries == 0) {
-    receive_failed("Unable to connect to UDP tracker.");
+    receive_failed("unable to connect to UDP tracker");
   } else {
     priority_queue_insert(&taskScheduler, &m_taskTimeout, (cachedTime + rak::timer::from_seconds(m_parent->info()->udp_timeout())).round_seconds());
 
@@ -232,7 +259,7 @@ TrackerUdp::event_read() {
   m_readBuffer->reset_position();
   m_readBuffer->set_end(s);
 
-  LT_LOG_TRACKER_DUMP(DEBUG, (const char*)m_readBuffer->begin(), s, "Tracker UDP reply.", 0);
+  LT_LOG_TRACKER_DUMP(DEBUG, (const char*)m_readBuffer->begin(), s, "received reply", 0);
 
   if (s < 4)
     return;
@@ -278,10 +305,6 @@ TrackerUdp::event_write() {
 
   int __UNUSED s = write_datagram(m_writeBuffer->begin(), m_writeBuffer->size_end(), &m_connectAddress);
 
-  // TODO: If send failed, retry shortly or do i call receive_failed?
-  // if (s != m_writeBuffer->size_end())
-  //   ;
-
   manager->poll()->remove_write(this);
 }
 
@@ -297,7 +320,7 @@ TrackerUdp::prepare_connect_input() {
   m_writeBuffer->write_32(m_transactionId = random());
 
   LT_LOG_TRACKER_DUMP(DEBUG, m_writeBuffer->begin(), m_writeBuffer->size_end(),
-                      "Tracker UDP connect: id:%" PRIx32 ".", m_transactionId);
+                      "prepare connect (id:%" PRIx32 ")", m_transactionId);
 }
 
 void
@@ -324,11 +347,12 @@ TrackerUdp::prepare_announce_input() {
 
   const rak::socket_address* localAddress = rak::socket_address::cast_from(manager->connection_manager()->local_address());
 
-  // This code assumes we're have a inet address.
-  if (localAddress->family() != rak::socket_address::af_inet)
-    throw internal_error("TrackerUdp::prepare_announce_input() info->local_address() not of family AF_INET.");
+  uint32_t local_addr = 0;
 
-  m_writeBuffer->write_32_n(localAddress->sa_inet()->address_n());
+  if (localAddress->family() == rak::socket_address::af_inet)
+    local_addr = localAddress->sa_inet()->address_n();
+
+  m_writeBuffer->write_32_n(local_addr);
   m_writeBuffer->write_32(m_parent->key());
   m_writeBuffer->write_32(m_parent->numwant());
   m_writeBuffer->write_16(manager->connection_manager()->listen_port());
@@ -337,7 +361,7 @@ TrackerUdp::prepare_announce_input() {
     throw internal_error("TrackerUdp::prepare_announce_input() ended up with the wrong size");
 
   LT_LOG_TRACKER_DUMP(DEBUG, m_writeBuffer->begin(), m_writeBuffer->size_end(),
-                      "Tracker UDP announce: state:%s id:%" PRIx32 " up_adj:%" PRIu64 " completed_adj:%" PRIu64 " left_adj:%" PRIu64 ".",
+                      "prepare announce (state:%s id:%" PRIx32 " up_adj:%" PRIu64 " completed_adj:%" PRIu64 " left_adj:%" PRIu64 ")",
                       option_as_string(OPTION_TRACKER_EVENT, m_sendState),
                       m_transactionId, uploaded_adjusted, completed_adjusted, download_left);
 }
@@ -385,7 +409,7 @@ TrackerUdp::process_error_output() {
       m_readBuffer->read_32() != m_transactionId)
     return false;
 
-  receive_failed("Received error message: " + std::string(m_readBuffer->position(), m_readBuffer->end()));
+  receive_failed("received error message: " + std::string(m_readBuffer->position(), m_readBuffer->end()));
   return true;
 }
 
