@@ -1,7 +1,7 @@
 #include "config.h"
 
 #include <iostream>
-#include <tr1/functional>
+#include lt_tr1_functional
 
 #include "rak/priority_queue_default.h"
 
@@ -9,8 +9,6 @@
 #include "tracker_list_test.h"
 #include "tracker_controller_test.h"
 
-namespace tr1 { using namespace std::tr1; }
-
 CPPUNIT_TEST_SUITE_REGISTRATION(tracker_controller_test);
 
 bool
