@@ -7,13 +7,11 @@
 
 CPPUNIT_TEST_SUITE_REGISTRATION(utils_net_test);
 
-namespace tr1 { using namespace std::tr1; }
-
 static void inc_value(int* value) { (*value)++; }
 
 #define LTUNIT_AI_CALL(lt_ai, lt_flags) {                               \
   int test_value = 0;                                                   \
-  CPPUNIT_ASSERT(torrent::address_info_call(ai, 0, tr1::bind(&inc_value, &test_value))); \
+  CPPUNIT_ASSERT(torrent::address_info_call(ai, 0, std::bind(&inc_value, &test_value))); \
   CPPUNIT_ASSERT(test_value); }                                         \
 
 void
